@@ -21,8 +21,4 @@ class GBL:
         if not self.token:
             raise errors.InvalidKey("A token was not supplied")
 
-        async with aiohttp.ClientSession() as session:
-            async with session.post(url=self.base + f"{botid}/stats", data={"serverCount": servers}, headers={"authorization": self.token}) as resp:
-                r = resp.json
-        #if r.status != 200:
-         #   raise errors.InvalidKey("The token provided was not valid")
+        await aiohttp.ClientSession().post(url=self.base + f"{botid}/stats", data={"serverCount": servers}, headers={"authorization": self.token})
